@@ -26,7 +26,7 @@ def _create_path_folder(data_path):
     if not os.path.exists(data_path):
         try:
             os.mkdir(data_path)
-        except:
+        except Exception as exc_:
             raise RuntimeError("Impossible to create a directory in \"{}\". Make sure you can write here. If you don't "
                                "have writing permissions there, you can edit / create a config file in \"{}\""
                                "and set the \"data_path\" to point to a path where you can store data."
