@@ -127,7 +127,8 @@ def _aux_run_one_episode(env,
         disc_lines = np.full((0, env.backend.n_line), fill_value=np.NaN, dtype=dt_bool)
         attack = np.full((0, env._opponent_action_space.n), fill_value=0., dtype=dt_float)
 
-    if path_save is not None:
+    need_store_first_act = path_save is not None or detailed_output
+    if need_store_first_act:
         # store observation at timestep 0
         if efficient_storing:
             observations[time_step, :] = obs.to_vect()
@@ -151,9 +152,12 @@ def _aux_run_one_episode(env,
                           name=env.chronics_handler.get_name(),
                           force_detail=detailed_output,
                           other_rewards=[])
+    if need_store_first_act:
+        # I need to manually force in the first observation (otherwise it's not computed)
+        episode.observations.objects[0] = episode.observations.helper.from_vect(observations[time_step, :])
     episode.set_parameters(env)
-
-    beg_ = time.time()
+   
+    beg_ = time.perf_counter()
 
     reward = float(env.reward_range[0])
     done = False
@@ -161,9 +165,9 @@ def _aux_run_one_episode(env,
     next_pbar = [False]
     with _aux_make_progress_bar(pbar, nb_timestep_max, next_pbar) as pbar_:
         while not done:
-            beg__ = time.time()
+            beg__ = time.perf_counter()
             act = agent.act(obs, reward, done)
-            end__ = time.time()
+            end__ = time.perf_counter()
             time_act += end__ - beg__
 
             obs, reward, done, info = env.step(act)  # should load the first time stamp
@@ -179,7 +183,7 @@ def _aux_run_one_episode(env,
                                act, obs, opp_attack,
                                info)
 
-        end_ = time.time()
+        end_ = time.perf_counter()
     episode.set_meta(env, time_step, float(cum_reward), env_seed, agent_seed)
 
     li_text = ["Env: {:.2f}s", "\t - apply act {:.2f}s", "\t - run pf: {:.2f}s",
